// All database related API calls

import { AuthorizationHandler } from '@graphpolaris/shared/data-access/authorization';

export type AddDatabaseRequest = {
  name: string;
  internal_database_name: string;
  url: string;
  port: number;
  username: string;
  password: string;
  type: number; // Database type. 0 = ArangoDB, 1 = Neo4j
};

export function AddDatabase(request: AddDatabaseRequest): Promise<void> {
  return new Promise((resolve, reject) => {
    fetch('https://datastrophe.science.uu.nl/user/database', {
      method: 'POST',
      credentials: 'same-origin',
      headers: new Headers({
        Authorization:
          'Bearer ' + AuthorizationHandler.instance().AccessToken(),
      }),
      body: JSON.stringify(request),
    }).then((response: Response) => {
      if (!response.ok) {
        reject(response.statusText);
      }

      resolve();
    });
  });
}

export function GetAllDatabases(): Promise<Array<string>> {
  return new Promise<Array<string>>((resolve, reject) => {
    fetch('https://datastrophe.science.uu.nl/user/database', {
      method: 'GET',
      credentials: 'same-origin',
      headers: new Headers({
        Authorization:
          'Bearer ' + AuthorizationHandler.instance().AccessToken(),
      }),
    })
      .then((response: Response) => {
        if (!response.ok) {
          reject(response.statusText);
        }

        return response.json();
      })
      .then((json: any) => {
        resolve(json.databases);
      });
  });
}

export function DeleteDatabase(name: string): Promise<void> {
  return new Promise((resolve, reject) => {
    fetch('https://datastrophe.science.uu.nl/user/database/' + name, {
      method: 'DELETE',
      credentials: 'same-origin',
      headers: new Headers({
        Authorization:
          'Bearer ' + AuthorizationHandler.instance().AccessToken(),
      }),
    }).then((response: Response) => {
      if (!response.ok) {
        reject(response.statusText);
      }

      resolve();
    });
  });
}
